@@ -135,7 +135,7 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
 {
     NetworkManager::AccessPoint::Ptr ap;
     NetworkManager::WirelessDevice::Ptr wifiDev;
-    Q_FOREACH(const NetworkManager::Device::Ptr & dev, NetworkManager::networkInterfaces()) {
+    Q_FOREACH (const NetworkManager::Device::Ptr & dev, NetworkManager::networkInterfaces()) {
         if (dev->type() == NetworkManager::Device::Wifi) {
             wifiDev = dev.objectCast<NetworkManager::WirelessDevice>();
             ap = wifiDev->findAccessPoint(specificObject);
@@ -191,14 +191,18 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         editor->show();
         KWindowSystem::setState(editor->winId(), NET::KeepAbove);
         KWindowSystem::forceActiveWindow(editor->winId());
-
-        if (editor->exec() == QDialog::Accepted) {
-            addConnection(editor->setting());
-        }
-
-        if (editor) {
-            editor->deleteLater();
-        }
+        connect(editor.data(), &ConnectionDetailEditor::accepted,
+                [editor, this] () {
+                    addConnection(editor->setting());
+                });
+        connect(editor.data(), &ConnectionDetailEditor::finished,
+                [editor] () {
+                    if (editor) {
+                        editor->deleteLater();
+                    }
+                });
+        editor->setModal(true);
+        editor->show();
     } else {
         if (securityType == NetworkManager::StaticWep) {
             wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::Wep);
@@ -246,15 +250,12 @@ void Handler::deactivateConnection(const QString& connection, const QString& dev
     }
 
     QDBusPendingReply<> reply;
-    Q_FOREACH(const NetworkManager::ActiveConnection::Ptr & active, NetworkManager::activeConnections()) {
+    Q_FOREACH (const NetworkManager::ActiveConnection::Ptr & active, NetworkManager::activeConnections()) {
         if (active->uuid() == con->uuid() && ((!active->devices().isEmpty() && active->devices().first() == device) ||
                                                active->vpn())) {
             if (active->vpn()) {
                 reply = NetworkManager::deactivateConnection(active->path());
             } else {
-                if (active->devices().isEmpty()) {
-                    reply = NetworkManager::deactivateConnection(connection);
-                }
                 NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(active->devices().first());
                 if (device) {
                     reply = device->disconnectInterface();
@@ -270,7 +271,7 @@ void Handler::deactivateConnection(const QString& connection, const QString& dev
 
 void Handler::disconnectAll()
 {
-    Q_FOREACH(const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
+    Q_FOREACH (const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
         device->disconnectInterface();
     }
 }
@@ -387,7 +388,7 @@ void Handler::removeConnection(const QString& connection)
     }
 
     // Remove slave connections
-    Q_FOREACH(const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
+    Q_FOREACH (const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
         NetworkManager::ConnectionSettings::Ptr settings = connection->settings();
         if (settings->master() == con->uuid()) {
             connection->remove();
@@ -417,7 +418,7 @@ void Handler::openEditor()
 
 void Handler::requestScan()
 {
-    Q_FOREACH(NetworkManager::Device::Ptr device, NetworkManager::networkInterfaces()) {
+    Q_FOREACH (NetworkManager::Device::Ptr device, NetworkManager::networkInterfaces()) {
         if (device->type() == NetworkManager::Device::Wifi) {
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
             if (wifiDevice) {
