@@ -18,19 +18,16 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "l2tp.h"
-
 #include <KPluginFactory>
-#include <KLocale>
-#include "nm-l2tp-service.h"
 
 #include <NetworkManagerQt/VpnSetting>
 
+#include "nm-l2tp-service.h"
+#include "l2tp.h"
 #include "l2tpwidget.h"
 #include "l2tpauth.h"
 
-K_PLUGIN_FACTORY(L2tpUiPluginFactory, registerPlugin<L2tpUiPlugin>();)
-K_EXPORT_PLUGIN(L2tpUiPluginFactory("plasmanetworkmanagement_l2tpui"))
+K_PLUGIN_FACTORY_WITH_JSON(L2tpUiPluginFactory, "plasmanetworkmanagement_l2tpui.json", registerPlugin<L2tpUiPlugin>();)
 
 L2tpUiPlugin::L2tpUiPlugin(QObject * parent, const QVariantList &):
     VpnUiPlugin(parent)
@@ -76,3 +73,5 @@ bool L2tpUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionSett
     mError = VpnUiPlugin::NotImplemented;
     return false;
 }
+
+#include "l2tp.moc"
