@@ -551,16 +551,21 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
         connect(buttons, SIGNAL(rejected()), dialog, SLOT(reject()));
         dialog->layout()->addWidget(widget);
         dialog->layout()->addWidget(buttons);
+        connect(dialog.data(), &QDialog::finished,
+                [accepted, dialog, widget] (int result) {
+                    if (result == QDialog::Accepted) {
+                        *accepted = true;
+                    } else {
+                        *accepted = false;
+                    }
 
-        if(dialog.data()->exec() == QDialog::Accepted) {
-            *accepted = true;
-        } else {
-            *accepted = false;
-        }
-        if (dialog) {
-            dialog.data()->deleteLater();
-        }
-        widget->deleteLater();
+                    if (dialog) {
+                        dialog->deleteLater();
+                    }
+                    widget->deleteLater();
+                });
+        dialog->setModal(true);
+        dialog->show();
     } else {
         *accepted = true;
     }
@@ -661,7 +666,7 @@ void OpenconnectAuthWidget::viewServerLogToggled(bool toggled)
     d->ui.lblLogLevel->setVisible(toggled);
     d->ui.cmbLogLevel->setVisible(toggled);
     if (toggled) {
-        QLayoutItem *item = d->ui.verticalLayout->takeAt(4);
+        QLayoutItem *item = d->ui.verticalLayout->takeAt(5);
         if (item) {
             delete item;
         }
