@@ -27,16 +27,13 @@
 #include "openconnectauth.h"
 
 K_PLUGIN_FACTORY(OpenconnectUiPluginFactory, registerPlugin<OpenconnectUiPlugin>();)
-K_EXPORT_PLUGIN(OpenconnectUiPluginFactory("plasmanetworkmanagement_openconnectui"))
 
 OpenconnectUiPlugin::OpenconnectUiPlugin(QObject * parent, const QVariantList &) : VpnUiPlugin(parent)
 {
-
 }
 
 OpenconnectUiPlugin::~OpenconnectUiPlugin()
 {
-
 }
 
 SettingWidget * OpenconnectUiPlugin::widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
@@ -83,3 +80,5 @@ bool OpenconnectUiPlugin::exportConnectionSettings(const NetworkManager::Connect
     mError = VpnUiPlugin::NotImplemented;
     return false;
 }
+
+#include "openconnectui.moc"
